import sys,os
sys.path.append(os.path.join(os.path.dirname(__file__),os.pardir,"src"))
import sida.slackbot.bot as bot

def test_send():
    assert bot.send("test_slackbot", 69)==-1
    assert bot.send("test_slackbot", 70)==0


import sys,os
sys.path.append(os.path.join(os.path.dirname(__file__),os.pardir,"src"))
import sida

def test_version():
    assert sida.__version__ == "0.0.8"

def test_fullname():
    # test full name, run by travis
    assert sida.fullname() == "Sida Liu"

def test_travis():
    assert True

def test_numpy_version():
    version = float(".".join("1.17.1".split(".")[:2]))
    assert version >= 1.16



import sys,os
sys.path.append(os.path.join(os.path.dirname(__file__),os.pardir,"src"))
import sida.cs228.standardize as std
import numpy as np
import pickle

def test_do():
    data = np.random.rand(5,4,6,1)
    data = std.do(data)

def test_true_data():
    with open("test/test_data/Liu_train2.p", "rb") as f:
        u = pickle._Unpickler(f)
        u.encoding = 'latin1'
        data = u.load()
    data = std.do(data)

def test_true_data_1():
    with open("test/test_data/Liu_train2.p", "rb") as f:
        u = pickle._Unpickler(f)
        u.encoding = 'latin1'
        data = u.load()
    data = std.do(data)
    # If want to write new result for future comparison:
    # with open("test/test_data/Liu_train2_std.p", "wb") as f:
    #     pickle.dump(data, f)
    with open("test/test_data/Liu_train2_std.p", "rb") as f:
        data_1 = pickle.load(f)
    assert np.array_equal(data, data_1)

if __name__ == "__main__":
    test_true_data_1()


from setuptools import setup

with open("README.md","r") as fh:
    long_description = fh.read()

setup(
    name='sida',
    version='0.0.8',
    description='My first pip package',
    py_modules=["sida"],
    scripts=["bin/sida"],
    package_dir={'':'src/sida'},
    install_requires=[
        'numpy',
        'matplotlib',
        'websocket-client'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    url="https://github.com/liusida/sida",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Sida Liu",
    author_email="learner.sida.liu@gmail.com",
)


import sys,os
sys.path.append(os.path.join(os.path.dirname(__file__),os.pardir,"src"))
import sida.cs228.show as show
import pickle

def test_show():
    with open("test/test_data/Liu_train2_std.p", "rb") as f:
        data = pickle.load(f)
    show.show_hand(data[:,:,:,0], view_point="front", scale="unit", fname="test/test_data/Liu_train2_std_front.png")
    show.show_hand(data[:,:,:,0], view_point="side", scale="unit", fname="test/test_data/Liu_train2_std_side.png")

if __name__ == "__main__":
    test_show()